from django.conf import settings


# Creating all the defaults for settings.
# In our code, if we want to use a DITTO_* setting we should import
# from here, not django.conf.settings.

# e.g. "07:34"
CORE_TIME_FORMAT = getattr(settings, 'DITTO_CORE_TIME_FORMAT', '%H:%M')

# e.g. "8 Apr 2018"
CORE_DATE_FORMAT = getattr(settings, 'DITTO_CORE_DATE_FORMAT', '%-d %b %Y')

# e.g. "07:34 on 8 Apr 2018"
CORE_DATETIME_FORMAT = getattr(
                settings, 'DITTO_CORE_DATETIME_FORMAT', '[time] on [date]')

# e.g. "2018"
CORE_DATE_YEAR_FORMAT = getattr(settings, 'DITTO_CORE_DATE_YEAR_FORMAT', '%Y')

# e.g. "Apr 2018"
CORE_DATE_YEAR_MONTH_FORMAT = getattr(
                settings, 'DITTO_CORE_DATE_YEAR_MONTH_FORMAT', '%b %Y')



# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-04-28 15:26
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pinboard', '0019_auto_20160428_1525'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bookmark',
            name='url_hash',
            field=models.CharField(db_index=True, help_text="Slug in the Bookmark's URL here.", max_length=12),
        ),
    ]



# Generated by Django 2.0 on 2018-01-04 14:57

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('flickr', '0022_photo_taken_year'),
    ]

    operations = [
        migrations.AlterField(
            model_name='photoset',
            name='primary_photo',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='primary_photosets', to='flickr.Photo'),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-05-25 10:11
from __future__ import unicode_literals

import ditto.twitter.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('twitter', '0036_auto_20160505_1156'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='avatar',
            field=models.ImageField(blank=True, default='', upload_to=ditto.twitter.models.User.avatar_upload_path),
        ),
    ]
